/*
*   ParamVerifier - Verifies that the value entered by a user in a parameter is valid.
*
*   Copyright (C) 1998-2012 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.ParamTools;

import java.awt.Component;

import jahuwaldt.js.param.Parameter;


/**
*  <p>  An interface for creating a parameter verifier method object.	</p>
*
*  <p>  Parameter Verifier objects contain a method for determining if
*       a value entered into a parameter by a user is valid.  A {@link AdvParam} object
*       can be optionally assigned a ParamVerifier.  When a user enters
*       a value for that parameter via a {@link AdvParamInput} text box, the value is
*       first run past the verifier to see if it is valid.  If it is not,
*       the verifier deals with it (by telling the user, making the value
*       valid, and/or returning Double.NaN if the value can not be made valid).
*  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author  Joseph A. Huwaldt   Date: September 30, 1998
*  @version May 27, 2012
**/
public interface ParamVerifier extends java.io.Serializable {

	/**
	*  User supplied method to see if the input value for this parameter is valid.
	*
	*  @param   root   The root component containing the parameter input text field
	*                  for the parameter being verified.
	*  @param   value  The value of the parameter as input by the user.
	*  @return  If "value" is valid, it should be output unchanged.
	*           If "value" is invalid or out of range, a valid value is output
	*           or Double.NaN if nothing else.  If ParamInput (which calls
	*           this routine) receives a value of Double.NaN, it will clear
	*           the parameter.
	**/
	public Parameter<?> check( Component root, Parameter<?> value );

}


