/*
*   Mfn_VT_a -- Calculates Mach number as a function of VT and a.
*   
*   Copyright (C) 1999 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Dimensionless;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the Mach number based on true airspeed
*  and the speed of sound at altitude.
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 18, 1998
*  @version  July 23, 2011
**/
public class Mfn_VT_a extends AbstractParamMethod<Dimensionless> {
	
	/**
	*  Constructor for this method.
	*
	*  @param  VT  Label for the "true airspeed" parameter.
	*  @param  a   Label for the "speed of sound" parameter.
	**/
	public Mfn_VT_a(String VT, String a) {
		_inputLabels = new String[2];
		_inputLabels[0] = VT;
		_inputLabels[1] = a;
	}
	
	
	/**
	*  Calculates the Mach number based on true airspeed and the speed of sound
	*  at altitude.
	*  Method:  M = VT/a
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=true airspeed (VT), 1=speed of sound (a)].
	*  @return  Mach number (M).
	**/
	public Parameter<Dimensionless> calc(Parameter[] inputs) {
		double VT = inputs[0].getValue();
		double a = inputs[1].doubleValue(inputs[0].getUnit());
		
		double M = VT/a;
		
		return Parameter.valueOf(M,Dimensionless.UNIT);
	}

}
