/*
*   Pfn_delta -- Calculates static pressure as a function of delta.
*   
*   Copyright (C) 1999 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Pressure;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the static air pressure based on pressure
*  ratio.
*
*  <p>  Modified by:  Joseph A. Huwaldt   </p>
*
*  @author  Joseph A. Huwaldt  Date: October 13, 1998
*  @version July 24, 2011
**/
public class Pfn_delta extends AbstractParamMethod<Pressure> implements AtmosSharedData {
	
	/**
	*  Constructor for this method.
	*
	*  @param   delta  Label for the "static pressure ratio" parameter.
	**/
	public Pfn_delta(String delta) {
		_inputLabels = new String[1];
		_inputLabels[0] = delta;
	}
	
	
	/**
	*  Calculates the static air pressure based on pressure ratio.
	*  Method:  P = P0*delta
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=pressure ratio (delta)].
	*  @return  Pressure (P).
	**/
	public Parameter<Pressure> calc(Parameter[] inputs) {
		Parameter delta = inputs[0];
		
		Parameter pressure = atmosModel.P0().times(delta);
		
		return pressure;
	}

}
