/*
*   qbarfn_VE -- Calculates dynamic pressure as a function of VE.
*   
*   Copyright (C) 1998 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Pressure;
import javax.measure.quantity.Velocity;
import javax.measure.quantity.VolumetricDensity;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates dynamic pressure based on equivalent airspeed.
*
*  <p>  Modified by:  Joseph A. Huwaldt   </p>
*
*  @author   Joseph A. Huwaldt  Date: October 18, 1998
*  @version  July 6, 2012
**/
public class qbarfn_VE extends AbstractParamMethod<Pressure> implements AtmosSharedData {
	
	/**
	*  Constructor for this method.
	*
	* @param   VE  Label for the "equivalent airspeed" parameter.
	**/
	public qbarfn_VE(String VE) {
		_inputLabels = new String[1];
		_inputLabels[0] = VE;
	}
	
	
	/**
	*  Calculates dynamic pressure based on equivalent airspeed.
	*  Method:  qbar = 1/2*RHO0*VE^2
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=equivalent airspeed (VE)].
	*  @return  Dynamic pressure (qbar) in N/m^2.
	**/
	public Parameter<Pressure> calc(Parameter[] inputs) {
		Parameter<Velocity> VE = inputs[0];
		Parameter<VolumetricDensity> rho0 = atmosModel.RHO0();
		
		Parameter<Pressure> qbar = rho0.times(VE.pow(2)).divide(2).to(Pressure.UNIT);
		
		return qbar;
	}

}


