/*
*   sigmafn_VE_VT -- Calculates density ratio as a function of VE & VT.
*   
*   Copyright (C) 1999 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Dimensionless;
import javax.measure.quantity.Velocity;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the density ratio based on equivalent and true airspeed.
*
*  <p>  Modified by:  Joseph A. Huwaldt   </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 18, 1998
*  @version  July 23, 2011
**/
public class sigmafn_VE_VT extends AbstractParamMethod<Dimensionless> {
	
	/**
	*  Constructor for this method.
	*
	*  @param   VE  Label for the "equivalent airspeed" parameter.
	*  @param   VT  Label for the "true airspeed" parameter.
	**/
	public sigmafn_VE_VT(String VE, String VT) {
		_inputLabels = new String[2];
		_inputLabels[0] = VE;
		_inputLabels[1] = VT;
	}
	
	
	/**
	*  Calculates the density ratio based on true and equivalent airspeed.
	*  Method:  sigma = (VE/VT)^2
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=equivalent airspeed (VE), 1=true airspeed (VT)].
	*  @return  Density ratio (rho/rho_o).
	**/
	public Parameter<Dimensionless> calc(Parameter[] inputs) {
		double VE = inputs[0].getValue();
		double VT = inputs[1].doubleValue(inputs[0].getUnit());
		
		double sigma = VE/VT;
		sigma *= sigma;
		
		return Parameter.valueOf(sigma, Dimensionless.UNIT);
	}

}


